Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Elastic File System.

Actions, resources, and condition keys for Amazon Elastic File System - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Elastic File System

Amazon Elastic File System (service prefix: `elasticfilesystem` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Elastic File System
- Resource types defined by Amazon Elastic File System
- Condition keys for Amazon Elastic File System

## Actions defined by Amazon Elastic File System

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
Backup [permission only] | Grants permission to start a backup job for an existing file system | Write | file-system* |  |
ClientMount [permission only] | Grants permission to allow an NFS client read-access to a file system | Read | file-system* |  |
| elasticfilesystem:AccessPointArn elasticfilesystem:AccessedViaMountTarget |
ClientRootAccess [permission only] | Grants permission to allow an NFS client root-access to a file system | Write | file-system* |  |
| elasticfilesystem:AccessPointArn elasticfilesystem:AccessedViaMountTarget |
ClientWrite [permission only] | Grants permission to allow an NFS client write-access to a file system | Write | file-system* |  |
| elasticfilesystem:AccessPointArn elasticfilesystem:AccessedViaMountTarget |
CreateAccessPoint | Grants permission to create an access point for the specified file system | Write | file-system* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
CreateFileSystem | Grants permission to create a new, empty file system | Write |  | aws:RequestTag/${TagKey} aws:TagKeys elasticfilesystem:Encrypted |
CreateMountTarget | Grants permission to create a mount target for a file system | Write | file-system* |  |
CreateReplicationConfiguration | Grants permission to create a new replication configuration | Write | file-system* |  |
CreateTags | Grants permission to create or overwrite tags associated with a file system; deprecated, see TagResource | Tagging | file-system* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAccessPoint | Grants permission to delete the specified access point | Write | access-point* |  |
DeleteFileSystem | Grants permission to delete a file system, permanently severing access to its contents | Write | file-system* |  |
DeleteFileSystemPolicy | Grants permission to delete the resource-level policy for a file system | Permissions management | file-system* |  |
DeleteMountTarget | Grants permission to delete the specified mount target | Write | file-system* |  |
DeleteReplicationConfiguration | Grants permission to delete a replication configuration | Write | file-system* |  |
DeleteTags | Grants permission to delete the specified tags from a file system; deprecated, see UntagResource | Tagging | file-system* |  |
| aws:TagKeys |
DescribeAccessPoints | Grants permission to view the descriptions of Amazon EFS access points | List | access-point |  |
file-system |  |
DescribeAccountPreferences | Grants permission to view the account preferences in effect for an account | List |  |  |
DescribeBackupPolicy | Grants permission to view the BackupPolicy object for an Amazon EFS file system | Read | file-system* |  |
DescribeFileSystemPolicy | Grants permission to view the resource-level policy for an Amazon EFS file system | Read | file-system |  |
DescribeFileSystems | Grants permission to view the description of an Amazon EFS file system specified by file system CreationToken or FileSystemId; or to view the description of all file systems owned by the caller's AWS account in the AWS region of the endpoint that is being called | List | file-system |  |
DescribeLifecycleConfiguration | Grants permission to view the LifecycleConfiguration object for an Amazon EFS file system | Read | file-system* |  |
DescribeMountTargetSecurityGroups | Grants permission to view the security groups in effect for a mount target | Read | file-system* |  |
DescribeMountTargets | Grants permission to view the descriptions of all mount targets, or a specific mount target, for a file system | Read | file-system* |  |
access-point |  |
DescribeReplicationConfigurations | Grants permission to view the description of an Amazon EFS replication configuration specified by FileSystemId; or to view the description of all replication configurations owned by the caller's AWS account in the AWS region of the endpoint that is being called | List | file-system |  |
DescribeTags | Grants permission to view the tags associated with a file system | Read | file-system* |  |
ListTagsForResource | Grants permission to view the tags associated with the specified Amazon EFS resource | Read | access-point |  |
file-system |  |
ModifyMountTargetSecurityGroups | Grants permission to modify the set of security groups in effect for a mount target | Write | file-system* |  |
PutAccountPreferences | Grants permission to set the account preferences of an account | Write |  |  |
PutBackupPolicy | Grants permission to enable or disable automatic backups with AWS Backup by creating a new BackupPolicy object | Write | file-system* |  |
PutFileSystemPolicy | Grants permission to apply a resource-level policy that defines the actions allowed or denied from given actors for the specified file system | Permissions management | file-system* |  |
PutLifecycleConfiguration | Grants permission to enable lifecycle management by creating a new LifecycleConfiguration object | Write | file-system* |  |
Restore [permission only] | Grants permission to start a restore job for a backup of a file system | Write | file-system* |  |
TagResource | Grants permission to create or overwrite tags associated with the specified Amazon EFS resource | Tagging | access-point |  |
file-system |  |
| aws:RequestTag/${TagKey} aws:TagKeys elasticfilesystem:CreateAction |
UntagResource | Grants permission to delete the specified tags from an Amazon EFS resource | Tagging | access-point |  |
file-system |  |
| aws:TagKeys |
UpdateFileSystem | Grants permission to update the throughput mode or the amount of provisioned throughput of an existing file system | Write | file-system* |  |

## Resource types defined by Amazon Elastic File System

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
file-system | `arn:$ { Partition}:elasticfilesystem:$ { Region}:$ { Account}:file-system/$ { FileSystemId}` | aws:ResourceTag/${TagKey}
access-point | `arn:$ { Partition}:elasticfilesystem:$ { Region}:$ { Account}:access-point/$ { AccessPointId}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon Elastic File System

Amazon Elastic File System defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a tag key and value pair that is allowed in the request | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair of a resource | String
aws:TagKeys | Filters access by a list of tag keys that are allowed in the request | ArrayOfString
elasticfilesystem:AccessPointArn | Filters access by the ARN of the access point used to mount the file system | String
elasticfilesystem:AccessedViaMountTarget | Filters access by whether the file system is accessed via mount targets | Bool
elasticfilesystem:CreateAction | Filters access by the name of a resource-creating API action | String
elasticfilesystem:Encrypted | Filters access by whether users can create only encrypted or unencrypted file systems | Bool

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.